@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "18.0.2";
+        "21.0.1";
 
     private static final String java_version_date =
-        "2022-07-19";
+        "2023-10-17";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "18.0.2+8";
+        "21.0.1+12";
 
     private static final String VERSION_NUMBER =
-        "18.0.2";
+        "21.0.1";
 
     private static final String VERSION_SPECIFICATION =
-        "18";
+        "21";
 
     private static final String VERSION_BUILD =
-        "8";
+        "12";
 
     private static final String VERSION_PRE =
         "";
@@ -70,13 +70,13 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "62.0";
+        "65.0";
 
     private static final String VENDOR =
         "N/A";
 
     private static final String VENDOR_URL =
-        "https://openjdk.java.net/";
+        "https://openjdk.org/";
 
     // The remaining VENDOR_* fields must not be final,
     // so that they can be redefined by jlink plugins
@@ -109,6 +109,10 @@ class VersionProps {
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
         props.put("java.specification.version", VERSION_SPECIFICATION);
+
+        // Uncomment next props.put call after the first maintenance release for a
+        // platform specification is done and set the MR number, starting at "1".
+        // props.put("java.specification.maintenance.version", "1");
         props.put("java.specification.name", "Java Platform API Specification");
         props.put("java.specification.vendor", "Oracle Corporation");
 
@@ -182,25 +186,13 @@ class VersionProps {
         }
     }
 
-    /**
-     * In case you were wondering this method is called by java -version.
-     */
-    public static void print(boolean err) {
-        print(err, false);
-    }
 
-    /**
-     * This is the same as print except that it adds an extra line-feed
-     * at the end, typically used by the -showversion in the launcher
-     */
-    public static void println(boolean err) {
-        print(err, true);
-    }
 
     /**
      * Print version info.
+     * In case you were wondering this method is called by java -version.
      */
-    private static void print(boolean err, boolean newln) {
+    private static void print(boolean err) {
         PrintStream ps = err ? System.err : System.out;
 
         /* First line: platform version. */
